import { Component } from '@tarojs/taro'
import './index.scss'
import { GetShopDetail } from '@/services/shop'
import ready from '@/utils/ready'

export default class Index extends Component {
  config = {
    navigationBarTitleText: '商家详情'
  }
  state = {
    DetailInfo: null
  }
  componentWillMount () {
    ready.queue(() => {
      GetShopDetail({ id: this.$router.params.id }).then((res) => {
        this.setState({
          DetailInfo: { ...res, tags: res.tags.split(',') || [] } || null
        })
        Taro.setNavigationBarTitle({ title: res.shopName })
      })
    })
  }
  //   转发
  onShareAppMessage = () => {
    // shareSavePoint({
    //   event: 'share',
    //   eventType: 'main',
    //   propertyName: '乐客联盟分享',
    //   sharePersonId: personId,
    //   targetId: 'league',
    //   data: '{}'
    // }, 'main')
    return {
      title: this.state.DetailInfo.shopName,//分享内容
      path: `/pages/league/detail?id=${this.state.DetailInfo.shopId}`,//分享地址
      imageUrl: null,
    }
  }
  OpenMap () {
    const coord = this.state.DetailInfo.lngLat.split(',')
    const latitude = parseFloat(coord[1])
    const longitude = parseFloat(coord[0])
    Taro.openLocation({
      latitude,
      longitude,
      name: this.state.DetailInfo.shopName,
      address: this.state.DetailInfo.address,
      scale: 18
    })
  }
  CallShop () {
    Taro.makePhoneCall({
      phoneNumber: this.state.DetailInfo.phone
    })
  }
  render () {
    const { DetailInfo } = this.state
    return (
      <View className='Page ShopDetailPage'>
        {
          DetailInfo !== null &&
          <View>
            <Image mode='widthFix' src={DetailInfo.shopLogo}></Image>
            <View className='ShopInfo'>
              <Text>{DetailInfo.shopName}</Text>
              <View className='Tag flex-h'>
                <View className='flex-item'>
                  <Text>
                    {
                      DetailInfo.tags.map((item) => (
                        item + ' '
                      ))
                    }
                  </Text>
                </View>
                {
                  DetailInfo.score - 0 > 0 ?
                    <Image mode='widthFix' src={require('@/assets/img/icon6.png')} />
                    :
                    <Image mode='widthFix' src={require('@/assets/img/icon7.png')} />
                }
                {
                  DetailInfo.score - 0 > 1 ?
                    <Image mode='widthFix' src={require('@/assets/img/icon6.png')} />
                    :
                    <Image mode='widthFix' src={require('@/assets/img/icon7.png')} />
                }
                {
                  DetailInfo.score - 0 > 2 ?
                    <Image mode='widthFix' src={require('@/assets/img/icon6.png')} />
                    :
                    <Image mode='widthFix' src={require('@/assets/img/icon7.png')} />
                }
                {
                  DetailInfo.score - 0 > 3 ?
                    <Image mode='widthFix' src={require('@/assets/img/icon6.png')} />
                    :
                    <Image mode='widthFix' src={require('@/assets/img/icon7.png')} />
                }
                {
                  DetailInfo.score - 0 > 4 ?
                    <Image mode='widthFix' src={require('@/assets/img/icon6.png')} />
                    :
                    <Image mode='widthFix' src={require('@/assets/img/icon7.png')} />
                }
                <Text className='Score'>￥{DetailInfo.costAvg || 0}/人</Text>
              </View>
              <View className='Address flex-h'>
                <View className='flex-item'>
                  <Text>地址：{DetailInfo.address}</Text>
                </View>
                <View className='ToMap' onClick={this.OpenMap}>地图导航</View>
                <Image mode='widthFix' src={require('@/assets/img/more.png')} />
              </View>
              <View className='Phone flex-h' onClick={this.CallShop}>
                <View className='flex-item'>
                  <Text>电话：{DetailInfo.phone}</Text>
                </View>
                <Image mode='widthFix' src={require('@/assets/img/icon13.png')} />
              </View>
            </View>
            <View className='Line'></View>
            <View className='DescTop'>
              <Text>商户信息</Text>
              <View></View>
            </View>
            <Image mode='widthFix' src={DetailInfo.shopDesc}></Image>
            <View className='ShopPhone'>
              <Text onClick={this.CallShop}>联系商家</Text>
            </View>
          </View>
        }
      </View>
    )
  }
}
