import { View } from '@tarojs/components'
import { Component } from '@tarojs/taro'
import './index.scss'
import { GetShopList, GetShopTypeList } from '@/services/shop'
import ready from '@/utils/ready'
import ShopItem from './item'
import { connect } from '@tarojs/redux'
import ListView from '@/components/ListView'

@connect(
  state => ({ ...state.city })
)
export default class Index extends Component {
  config = {
    navigationBarTitleText: '乐客联盟'
  }
  state = {
    isEmpty: false,
    SearchName: '',
    StoreList: [],
    NavList: [],
    PageNum: 1,
    hasMore: true,
    DataLock: false,
    CurrentTypeId: null,
    CityData: null
  }
  componentWillMount () {
    ready.queue(() => {
      const city = this.state.city || this.props.curCity
      this.setState({
        CityData: city,
        CurrentTypeId: this.$router.params.type || null
      }, () => {
        GetShopTypeList({ pageNum: 1, pageSize: 10 }).then((res) => {
          let Arr = res.records || []
          let aArr = [{ id: 'all', img: null, name: '全部' }]
          Arr.map((item) => {
            aArr.push({ id: item.typeId, img: item.thumb, name: item.typeName })
          })
          this.setState({
            NavList: aArr,
            PageNum: 1,
            StoreList: []
          }, () => {
            this.ToGetPageList()
          })
        })
      })
    })
  }
  ToGetPageList () {
    if (!this.state.hasMore || this.DataLock) return
    this.DataLock = true
    GetShopList({ pageNum: this.state.PageNum, pageSize: 10, typeId: this.state.CurrentTypeId !== 'all' ? this.state.CurrentTypeId : '', name: this.state.CurrentTypeId === 'all' ? decodeURI(this.$router.params.key) : '', sortField: 'sort_no' }).then((res) => {
      let Arr = res.records || []
      let aArr = []
      Arr.map((item) => {
        aArr.push({ ...item, badges: (item.badges || '').split(',') || [], lng: item.lngLat.split(',')[0], lat: item.lngLat.split(',')[1] })
      })
      this.setState({
        hasMore: res.total > this.state.StoreList.length + aArr.length,
        StoreList: this.state.StoreList.concat(aArr || [])
      }, () => {
        this.setState({
          isEmpty: !this.state.StoreList.length
        })
      })
      this.DataLock = false
    })
  }
  onPullDownRefresh = async (rest) => {
    this.setState({
      PageNum: 1,
      StoreList: [],
      hasMore: true
    }, () => {
      this.ToGetPageList()
      rest && rest()
    })
  }
  onScrollToLower = async (fn) => {
    this.setState({
      PageNum: this.state.PageNum + 1
    }, () => {
      this.ToGetPageList()
      fn && fn()
    })
  }
  GoBack () {
    Taro.navigateBack()
  }
  NavClick (item) {
    this.setState({
      CurrentTypeId: item.id
    }, () => {
      this.onPullDownRefresh()
    })
  }
  render () {
    const { NavList, StoreList, CityData, hasMore, isEmpty, CurrentTypeId } = this.state
    return (
      <View className='PageContainer LeKeListPage flex-v'>
        <View className='Nav'>
          <ScrollView scroll-x='true' className='NavScroll'>
            {
              NavList.map((item, index) => (
                <View key={`Nav-${index}`} className={item.id === CurrentTypeId ? 'active Item' : 'Item'} onClick={this.NavClick.bind(this, item)}>{item.name}</View>
              ))
            }
          </ScrollView>
        </View>
        <View className='flex-item'>
          <View>
            <ListView
              className="wrap"
              needInit
              isEmpty={isEmpty}
              emptyText="暂无商家~"
              hasMore={hasMore}
              onPullDownRefresh={fn => this.onPullDownRefresh(fn)}
              onScrollToLower={fn => this.onScrollToLower(fn)}
            >
              <View>

                {/* 乐客商家 */}
                <View className='LeKeStore'>
                  {
                    StoreList.map((item, index) => (
                      <View>
                        <View className='Line'></View>
                        <ShopItem item={item} lat={CityData.lat} lng={CityData.lng} key={`Store-${index}`}></ShopItem>
                      </View>
                    ))
                  }
                </View>

              </View>
            </ListView>
          </View>
        </View>
      </View>
    )
  }
}
